#############

=pod

There's no real example.

Keep in mind that you need to provide the API keys via an environmental variables APP_NOPASTE_PASTEBINCOM_API_KEY and
APP_NOPASTE_PASTEBINCOM_USER_KEY

See perldoc App::Nopaste::Service::PastebinComAPI to learn about
how to generate the USER key.

See docs for App::Nopaste

=cut

